2022-10-31 Version: 2.1.1
- Add CreateWorkitemComment and change some API params.

2022-10-29 Version: 2.1.0
- Add CreateWorkitemComment and change some API params.

2022-10-25 Version: 1.1.31
- Add UpdateProtectedBranches and change some API params.

2022-07-28 Version: 1.1.30
- Add PipelineGroup.

2022-07-27 Version: 1.0.29
- Update create repo.

2022-06-07 Version: 1.1.19
- Update Projex ErrorCode API.

2022-05-26 Version: 1.1.16
- Update Projex Workitem API.

2022-05-12 Version: 1.1.15
- Update Projex Workitem API.

2022-04-28 Version: 1.1.14
- Update Projex Workitem API.

2022-04-13 Version: 1.1.13
- Update Projex Workitem API.

2022-04-02 Version: 1.1.12
- Add Codeup Api.

2022-03-18 Version: 1.1.11
- Add Codeup Api.

2022-02-24 Version: 1.1.10
- Add CreateWorkitem Api.

2022-01-29 Version: 1.1.9
- Add CreateWorkitem Api.

2022-01-10 Version: 1.1.8
- Add CreateSprint Api.

2021-12-30 Version: 1.1.7
- Add GeyPipelinArtifactUrl Api.

2021-12-15 Version: 1.1.6
- Add Tag Api.

2021-11-26 Version: 1.1.5
- Add Deploy Api.

2021-11-26 Version: 1.1.4
- Add Deploy Api.

2021-11-25 Version: 1.1.2
- Add Deploy Api.

2021-11-17 Version: 1.0.4
- Add PipelineValidate API.

2021-09-27 Version: 1.0.3
- Add roleId for result.

2021-09-02 Version: 1.0.1
- Init.

2021-08-31 Version: 1.0.0
- Init.

